@@ -16,8 +16,8 @@
  
 package org.gnu.gdk;
 
-import org.gnu.javagnome.Handle;
-import org.gnu.javagnome.Struct;
+import org.gnu.glib.Handle;
+import org.gnu.glib.Struct;
 
 public class Atom extends Struct 
 {
