@@ -9,7 +9,7 @@
 
 package org.gnu.gdk;
 
-import org.gnu.javagnome.Handle;
+import org.gnu.glib.Handle;
 import org.gnu.glib.MemStruct;
 
 public class KeymapKey extends MemStruct
