@@ -9,11 +9,15 @@
 
 package org.gnu.gdk;
 
-import org.gnu.glib.Boxed;
 import org.gnu.glib.Handle;
 
-public class Property extends Boxed 
+public class Property
 {
+    /*
+     * This class should probably be iliminated or fully implemented.
+     * The native methods could be attached to gdk.Window.
+     */
+
     /****************************************
      * BEGINNING OF JNI CODE
      ****************************************/
