@@ -9,8 +9,8 @@
 
 package org.gnu.gtk;
 
-import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
+import org.gnu.glib.Handle;
 
 /**
  * This is the base class that holds the common functions for
@@ -82,4 +82,10 @@ public abstract class ButtonBox extends Box
     native static final protected void gtk_button_box_set_child_secondary (Handle widget, Handle child, boolean isSecondary);
     native static final protected boolean gtk_button_box_get_child_secondary(Handle widget, Handle child);
 
+    /* Deprecated functions.
+    native static final private void gtk_button_box_set_child_size(Handle widget, int min_width, int min_height);
+    native static final private void gtk_button_box_set_child_ipadding(Handle widget, int ipad_x, int ipad_y);
+    native static final private void gtk_button_box_get_child_size(Handle widget, int[] min_width, int[] min_height);
+    native static final private void gtk_button_box_get_child_ipadding(Handle widget, int[] ipad_x, int[] ipad_y);
+    */
 }
