@@ -16,7 +16,7 @@ import org.gnu.glib.EventType;
 import org.gnu.glib.Type;
 import org.gnu.gtk.event.CheckMenuItemEvent;
 import org.gnu.gtk.event.CheckMenuItemListener;
-import org.gnu.javagnome.Handle;
+import org.gnu.glib.Handle;
 
 /**
  * The CheckMenuItem is a menu item that maintains the state of a boolean
@@ -41,6 +41,20 @@ public class CheckMenuItem extends MenuItem {
 	public CheckMenuItem(Handle handle) {
 	    super(handle);
 	}
+    
+    /**
+     * Internal static factory method to be used by Java-Gnome only.
+     */
+    public static CheckMenuItem getCheckMenuItem(Handle handle) {
+        if (handle == null)
+            return null;
+        
+        CheckMenuItem obj = (CheckMenuItem) getGObjectFromHandle(handle);
+        if (obj == null)
+            obj = new CheckMenuItem(handle);
+        
+        return obj;
+    }
 
 	/**
 	 * Create a new CheckMenuItem with the given label.
