@@ -16,7 +16,7 @@ import org.gnu.glib.EventType;
 import org.gnu.glib.Type;
 import org.gnu.gtk.event.ExpanderEvent;
 import org.gnu.gtk.event.ExpanderListener;
-import org.gnu.javagnome.Handle;
+import org.gnu.glib.Handle;
 
 /** 
  * A container which can hide its child.
@@ -45,6 +45,20 @@ public class Expander extends Bin {
 	public Expander(Handle handle) {
 	    super(handle);
 	}
+    
+    /**
+     * Internal static factory method to be used by Java-Gnome only.
+     */
+    public static Expander getExpander(Handle handle) {
+        if (handle == null)
+            return null;
+        
+        Expander obj = (Expander) getGObjectFromHandle(handle);
+        if (obj == null)
+            obj = new Expander(handle);
+        
+        return obj;
+    }
 	
 	private static Handle init(String label, boolean hasMnemonic) {
 		if (hasMnemonic)
