@@ -11,12 +11,10 @@ package org.gnu.gtk;
 import java.util.ArrayList;
 import java.util.List;
 
-import org.gnu.glib.Error;
 import org.gnu.glib.EventMap;
+import org.gnu.glib.Handle;
 import org.gnu.gtk.event.FileChooserEvent;
 import org.gnu.gtk.event.FileChooserListener;
-import org.gnu.javagnome.Handle;
-import org.gnu.javagnome.Struct;
 
 /**
  */
@@ -36,6 +34,20 @@ public class FileChooserButton extends HBox implements FileChooser {
         super(handle);
     }
     
+    /**
+     * Internal static factory method to be used by Java-Gnome only.
+     */
+    public static FileChooserButton getFileChooserButton(Handle handle) {
+        if (handle == null)
+            return null;
+        
+        FileChooserButton obj = (FileChooserButton) getGObjectFromHandle(handle);
+        if (obj == null)
+            obj = new FileChooserButton(handle);
+        
+        return obj;
+    }
+    
     /**
      * Create a new FileChooserButton
      * @param title the title of the browse dialog
@@ -153,7 +165,7 @@ public class FileChooserButton extends HBox implements FileChooser {
      * @see org.gnu.gtk.FileChooser#setFilename(java.lang.String)
      */
     public boolean setFilename(String filename) {
-        return FileChooserHelper.gtk_file_chooser_set_filename(getHandle(), filename);
+        return FileChooserHelper.setFilename(getHandle(), filename);
     }
 
     /* (non-Javadoc)
@@ -371,24 +383,14 @@ public class FileChooserButton extends HBox implements FileChooser {
      * @see org.gnu.gtk.FileChooser#addShortcutFolder(java.lang.String)
      */
     public void addShortcutFolder(String folder) throws FileChooserException {
-        Handle errorHandle = Struct.getNullHandle();
-        FileChooserHelper.gtk_file_chooser_add_shortcut_folder(getHandle(), folder, errorHandle);
-        if (errorHandle.isNull() == false) {
-            Error error = new Error(errorHandle);
-            throw new FileChooserException(error.getErrorCode());
-        }
-}
+        FileChooserHelper.addShortcutFolder(getHandle(), folder);
+    }
 
     /* (non-Javadoc)
      * @see org.gnu.gtk.FileChooser#removeShortcutFolder(java.lang.String)
      */
     public void removeShortcutFolder(String folder) throws FileChooserException {
-        Handle errorHandle = Struct.getNullHandle();
-        FileChooserHelper.gtk_file_chooser_remove_shortcut_folder(getHandle(), folder, errorHandle);
-        if (errorHandle.isNull() == false) {
-            Error error = new Error(errorHandle);
-            throw new FileChooserException(error.getErrorCode());
-        }
+        FileChooserHelper.removeShortcutFolder(getHandle(), folder);
     }
 
     /* (non-Javadoc)
@@ -402,24 +404,14 @@ public class FileChooserButton extends HBox implements FileChooser {
      * @see org.gnu.gtk.FileChooser#addShortCutURI(java.lang.String)
      */
     public void addShortcutURI(String uri) throws FileChooserException {
-        Handle errorHandle = Struct.getNullHandle();
-        FileChooserHelper.gtk_file_chooser_add_shortcut_folder_uri(getHandle(), uri, errorHandle);
-        if (errorHandle.isNull() == false) {
-            Error error = new Error(errorHandle);
-            throw new FileChooserException(error.getErrorCode());
-        }
+        FileChooserHelper.addShortcutURI(getHandle(), uri);
     }
 
     /* (non-Javadoc)
      * @see org.gnu.gtk.FileChooser#removeShortcutURI(java.lang.String)
      */
     public void removeShortcutURI(String uri) throws FileChooserException {
-        Handle errorHandle = Struct.getNullHandle();
-        FileChooserHelper.gtk_file_chooser_remove_shortcut_folder_uri(getHandle(), uri, errorHandle);
-        if (errorHandle.isNull() == false) {
-            Error error = new Error(errorHandle);
-            throw new FileChooserException(error.getErrorCode());
-        }
+        FileChooserHelper.removeShortcutURI(getHandle(), uri);
     }
 
     /* (non-Javadoc)
