@@ -10,7 +10,7 @@
 package org.gnu.gtk;
 
 import org.gnu.glib.Type;
-import org.gnu.javagnome.Handle;
+import org.gnu.glib.Handle;
 
 /**
  * The FontSelectionDialog widget is a dialog for selecting a font.
@@ -38,6 +38,20 @@ public class FontSelectionDialog extends Dialog {
 	public FontSelectionDialog(Handle handle) {
 		super(handle);
 	}
+    
+    /**
+     * Internal static factory method to be used by Java-Gnome only.
+     */
+    public static FontSelectionDialog getFontSelectionDialog(Handle handle) {
+        if (handle == null)
+            return null;
+        
+        FontSelectionDialog obj = (FontSelectionDialog) getGObjectFromHandle(handle);
+        if (obj == null)
+            obj = new FontSelectionDialog(handle);
+        
+        return obj;
+    }
 
 	/**
 	 * Gets the currently selected font name.
