@@ -9,7 +9,7 @@
 
 package org.gnu.gtk;
 
-import org.gnu.javagnome.Handle;
+import org.gnu.glib.Handle;
 
 /**
  * The Progress widget is the base class of {@link ProgressBar}. The Progress
@@ -22,6 +22,20 @@ public class Progress extends Widget
 	Progress(Handle handle) {
 	    super(handle);
 	}
+    
+    /**
+     * Internal static factory method to be used by Java-Gnome only.
+     */
+    static Progress getProgress(Handle handle) {
+        if (handle == null)
+            return null;
+        
+        Progress obj = (Progress) getGObjectFromHandle(handle);
+        if (obj == null)
+            obj = new Progress(handle);
+        
+        return obj;
+    }
 
 	//
 	// This class is all deprecated as of Gnome 2
