@@ -16,7 +16,7 @@ import org.gnu.glib.EventType;
 import org.gnu.glib.Type;
 import org.gnu.gtk.event.RangeEvent;
 import org.gnu.gtk.event.RangeListener;
-import org.gnu.javagnome.Handle;
+import org.gnu.glib.Handle;
 
 /**
  * This is the base class for the group of widgets that involve graphic
