@@ -17,7 +17,7 @@ import org.gnu.glib.GObject;
 import org.gnu.glib.Type;
 import org.gnu.gtk.event.TextBufferEvent;
 import org.gnu.gtk.event.TextBufferListener;
-import org.gnu.javagnome.Handle;
+import org.gnu.glib.Handle;
 
 /**
  * The TextBuffer is the object used to store data to be displayed in a {@link
@@ -37,6 +37,9 @@ public class TextBuffer extends GObject {
 		super(handle);
 	}
     
+    /**
+     * Internal static factory method to be used by Java-Gnome only.
+     */
     protected static TextBuffer getTextBuffer(Handle handle) {
         if (handle == null)
             return null;
@@ -937,9 +940,7 @@ public class TextBuffer extends GObject {
 	 */
 	public TextTag createTag(String name) {
 		Handle hndl = create_tag(getHandle(), name);
-		if (null == hndl)
-			return null;
-		return new TextTag(hndl);
+		return TextTag.getTextTag(hndl);
 	}
 
 	native static final protected int gtk_text_buffer_get_type();
