@@ -12,13 +12,14 @@ package org.gnu.gtk;
 import java.util.ArrayList;
 import java.util.List;
 
-import org.gnu.glib.Boxed;
-import org.gnu.glib.Handle;
+import org.gnu.glib.GObject;
+import org.gnu.glib.MemStruct;
 import org.gnu.gtk.event.ToggleActionEntryListener;
+import org.gnu.glib.Handle;
 
 /**
  */
-public class ToggleActionEntry extends Boxed {
+public class ToggleActionEntry extends MemStruct {
 
 	/**
 	 * ToggleActionEntryListener objects that are interested in
@@ -36,26 +37,18 @@ public class ToggleActionEntry extends Boxed {
 			ToggleActionEntryListener listener) {
 
 		// create the native object
-		handle = allocate();
+		super(allocate());
 		// set the values
-		setName(handle, name);
-		setStockId(handle, stockId);
-		setLabel(handle, label);
-		setAccelerator(handle, accel);
-		setToolTip(handle, tooltip);
-		setActive(handle, isActive);
+		setName(getHandle(), name);
+		setStockId(getHandle(), stockId);
+		setLabel(getHandle(), label);
+		setAccelerator(getHandle(), accel);
+		setToolTip(getHandle(), tooltip);
+		setActive(getHandle(), isActive);
 		if (null != listener) {
 			listeners.add(listener);
 		}
 	}
-		
-	/* (non-Javadoc)
-	 * @see java.lang.Object#finalize()
-	 */
-	protected void finalize() throws Throwable {
-		super.finalize();
-		free(handle);
-	}
 
 	public void addListener(ToggleActionEntryListener listener) {
 		listeners.add(listener);
@@ -65,10 +58,18 @@ public class ToggleActionEntry extends Boxed {
 		listeners.remove(listener);
 	}
 
-	private void handleCallback(Handle action) {
+	private void handleCallback(Handle actionHandle) {
+        if (actionHandle == null)
+            return;
+        
+        ToggleAction toggleAction = (ToggleAction)
+                GObject.getGObjectFromHandle(actionHandle);
+        if (toggleAction == null)
+            toggleAction = new ToggleAction(actionHandle);
+        
 		for (int i = 0; i < listeners.size(); i++) {
 			ToggleActionEntryListener l = (ToggleActionEntryListener)listeners.get(i);
-			l.actionEvent(new ToggleAction(action));
+			l.actionEvent(toggleAction);
 		}
 		
 	}
