@@ -16,7 +16,7 @@ import org.gnu.glib.EventType;
 import org.gnu.glib.Type;
 import org.gnu.gtk.event.TreeViewEvent;
 import org.gnu.gtk.event.TreeViewListener;
-import org.gnu.javagnome.Handle;
+import org.gnu.glib.Handle;
 
 /**
  * The TreeView object is a widget for displaying trees and lists. The sole
@@ -385,8 +385,7 @@ public class TreeView extends Container {
 	 * Returns the current path
 	 */
 	public TreePath getCursorPath() {
-		Handle path = getNullHandle();
-		gtk_tree_view_get_cursor(getHandle(), path, null);
+		Handle path = gtk_tree_view_get_cursor_path(getHandle());
 		return TreePath.getTreePath(path);
 	}
 
@@ -394,8 +393,7 @@ public class TreeView extends Container {
 	 * Returns the current column 
 	 */
 	public TreeViewColumn getCursorColumn() {
-		Handle column = getNullHandle();
-		gtk_tree_view_get_cursor(getHandle(), null, column);
+		Handle column = gtk_tree_view_get_cursor_column(getHandle());
 		return TreeViewColumn.getTreeViewColumn(column);
 	}
 
@@ -1527,7 +1525,8 @@ public class TreeView extends Container {
 	native static final protected boolean gtk_tree_view_get_reorderable(Handle treeView);
 	native static final protected void gtk_tree_view_set_cursor(Handle treeView, Handle path, Handle focusColumn, boolean startEditing);
 	native static final protected void gtk_tree_view_set_cursor_on_cell(Handle treeView, Handle path, Handle focusColumn, Handle focusCell, boolean startEditin);
-	native static final protected void gtk_tree_view_get_cursor(Handle treeView, Handle path, Handle focusColumn);
+    native static final protected Handle gtk_tree_view_get_cursor_path(Handle treeView);
+    native static final protected Handle gtk_tree_view_get_cursor_column(Handle treeView);
 	native static final protected Handle gtk_tree_view_get_bin_window(Handle treeView);
 	native static final protected boolean gtk_tree_view_get_path_at_pos(Handle treeView, int x, int y, Handle path, Handle column, int cellX, int cellY);
     //	native static final protected int gtk_tree_view_get_cell_area(int treeView, int path, int column);
