@@ -17,7 +17,7 @@ import org.gnu.glib.GObject;
 import org.gnu.glib.Type;
 import org.gnu.gtk.event.TreeViewColumnEvent;
 import org.gnu.gtk.event.TreeViewColumnListener;
-import org.gnu.javagnome.Handle;
+import org.gnu.glib.Handle;
 
 /**
  * The TreeViewColumn object is a visible column in a {@link TreeView} widget,
@@ -37,6 +37,9 @@ public class TreeViewColumn extends GObject {
 		super(handle);
 	}
     
+    /**
+     * Internal static factory method to be used by Java-Gnome only.
+     */
     protected static TreeViewColumn getTreeViewColumn(Handle handle) {
         if (handle == null)
             return null;
