@@ -1,7 +1,7 @@
 /*
  * Java-Gnome Bindings Library
  *
- * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
+ * Copyright 1998-2005 the Java-Gnome Team, all rights reserved.
  *
  * The Java-Gnome bindings library is free software distributed under
  * the terms of the GNU Library General Public License version 2.
@@ -15,9 +15,8 @@ import org.gnu.gdk.Pixbuf;
 import org.gnu.gdk.Point;
 import org.gnu.gdk.Screen;
 import org.gnu.gdk.WindowHints;
-import org.gnu.glib.GObject;
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
-import org.gnu.javagnome.Handle;
 
 /**
  * A Window is a window that can be displayed on the screen. It also
@@ -27,6 +26,8 @@ import org.gnu.javagnome.Handle;
  */
 public class Window extends Bin {
     
+    private boolean destroyed = false;
+    
     /**
      * Constructs a top-level Window. This is the same as calling
      * <code>new Window(WindowType.TOPLEVEL)</code>
@@ -77,11 +78,13 @@ public class Window extends Bin {
 	 * @param title A string containing the title for this Window
 	 */
 	public void setTitle(String title) {
-            if ( title != null ) {
-		Window.gtk_window_set_title(getHandle(), title);
-            } else {
-		Window.gtk_window_set_title(getHandle(), "");
-            }
+        checkState();
+        if (title != null) {
+            Window.gtk_window_set_title(getHandle(), title);
+        }
+        else {
+            Window.gtk_window_set_title(getHandle(), "");
+        }
 	}
 
 	/**
@@ -90,6 +93,7 @@ public class Window extends Bin {
 	 * @return A string containing the title.
 	 */
 	public String getTitle() {
+        checkState();
 		return Window.gtk_window_get_title(getHandle());
 	}
 
@@ -100,6 +104,7 @@ public class Window extends Bin {
 	 * @param resizable Determines if the window can be resized.
 	 */
 	public void setResizable(boolean resizable) {
+        checkState();
 		Window.gtk_window_set_resizable(getHandle(), resizable);
 	}
 	
@@ -109,6 +114,7 @@ public class Window extends Bin {
 	 * @param accelGroup	The AccelGroup to associate with this window.
 	 */
 	public void addAccelGroup(AccelGroup accelGroup) {
+        checkState();
 		Window.gtk_window_add_accel_group(getHandle(), accelGroup.getHandle());
 	}
 	
@@ -118,6 +124,7 @@ public class Window extends Bin {
 	 * @param accelGroup The AccelGroup to disassociate with this window.
 	 */
 	public void removeAccelGroup(AccelGroup accelGroup) {
+        checkState();
 		Window.gtk_window_remove_accel_group(getHandle(), accelGroup.getHandle());
 	}
 	
@@ -127,6 +134,7 @@ public class Window extends Bin {
 	 * @param modal Indicates whether the window should be modal or not.
 	 */
 	public void setModal(boolean modal) {
+        checkState();
 		Window.gtk_window_set_modal(getHandle(), modal);
 	}
 
@@ -138,6 +146,7 @@ public class Window extends Bin {
 	 * @param height the height to set for the default size.
 	 */
 	public void setDefaultSize(int width, int height) {
+        checkState();
 		Window.gtk_window_set_default_size(getHandle(), width, height);
 	}
 	
@@ -151,7 +160,9 @@ public class Window extends Bin {
 	 * @param geomMask Mask indicating which fields should be paid attention to.
 	 */
 	public void setGeometryHints(Widget geometryWidget, Geometry geometry, WindowHints geomMask) {
-		Window.gtk_window_set_geometry_hints(getHandle(), geometryWidget.getHandle(), geometry.getHandle(), geomMask.getValue());
+        checkState();
+		Window.gtk_window_set_geometry_hints(getHandle(),
+                geometryWidget.getHandle(), geometry.getHandle(), geomMask.getValue());
 	}
 	
 	/**
@@ -160,6 +171,7 @@ public class Window extends Bin {
 	 * @param gravity The window gravity.
 	 */
 	public void setGravity(	Gravity gravity) {
+        checkState();
 		Window.gtk_window_set_gravity(getHandle(), gravity.getValue());
 	}	
 	
@@ -169,6 +181,7 @@ public class Window extends Bin {
 	 * @return The Gravity for the Window.
 	 */
 	public Gravity getGravity() {
+        checkState();
 		int val = Window.gtk_window_get_gravity(getHandle());
 		return Gravity.intern(val);
 	}	
@@ -181,6 +194,7 @@ public class Window extends Bin {
 	 * @param position A position constraint.
 	 */
 	public void setPosition(WindowPosition position) {
+        checkState();
 		Window.gtk_window_set_position(getHandle(), position.getValue());
 	}
 	
@@ -190,6 +204,7 @@ public class Window extends Bin {
 	 * @return The Widget that has focus.
 	 */
 	public Widget getFocusWidget() {
+        checkState();
 	    Handle hndl = gtk_window_get_focus(getHandle());
 		return Widget.getWidget(hndl);
 	}
@@ -201,6 +216,7 @@ public class Window extends Bin {
 	 * @param focus The widget to receive focus for the Window.
 	 */
 	public void setFocusWidget(Widget focus) {
+        checkState();
 		Window.gtk_window_set_focus(getHandle(), focus.getHandle());
 	}
 	
@@ -212,6 +228,7 @@ public class Window extends Bin {
 	 * @param defaultWidget The widget that should become the default widget.
 	 */
 	public void setDefaultWidget(Widget defaultWidget) {
+        checkState();
 		Window.gtk_window_set_default(getHandle(), defaultWidget.getHandle());
 	}	
 
@@ -223,6 +240,7 @@ public class Window extends Bin {
 	 * show</code> as well.
 	 */
 	public void present() {
+        checkState();
 		Window.gtk_window_present(getHandle());
 	}
 	
@@ -232,6 +250,7 @@ public class Window extends Bin {
 	 * not be a window manager in which case iconification is not possible. 
 	 */
 	public void iconify() {
+        checkState();
 		Window.gtk_window_iconify(getHandle());
 	}
 	
@@ -239,6 +258,7 @@ public class Window extends Bin {
 	 * Asks to deiconify the specified Window. 
 	 */
 	public void deiconify() {
+        checkState();
 		Window.gtk_window_deiconify(getHandle());
 	}
 	
@@ -249,6 +269,7 @@ public class Window extends Bin {
 	 * the Window or the window manager may not support this feature.
 	 */
 	public void stick() {
+        checkState();
 		Window.gtk_window_stick(getHandle());
 	}
 	
@@ -256,6 +277,7 @@ public class Window extends Bin {
 	 * Asks to unstick the window.
 	 */
 	public void unstick() {
+        checkState();
 		Window.gtk_window_unstick(getHandle());
 	}
 	
@@ -263,6 +285,7 @@ public class Window extends Bin {
 	 * Asks to maximize the Window so it becomes full-screen.
 	 */
 	public void maximize() {
+        checkState();
 		Window.gtk_window_maximize(getHandle());
 	}
 	
@@ -270,6 +293,7 @@ public class Window extends Bin {
 	 * Asks to unmaximize the Window so it becomes it normal size.
 	 */
 	public void unmaximize() {
+        checkState();
 		Window.gtk_window_unmaximize(getHandle());
 	}
 	
@@ -281,6 +305,7 @@ public class Window extends Bin {
 	 * @param setting Determines if the Window should be decorated.
 	 */
 	public void setDecorated(boolean setting) {
+        checkState();
 		Window.gtk_window_set_decorated(getHandle(), setting);
 	}
 	
@@ -292,6 +317,7 @@ public class Window extends Bin {
 	 * @return The size of the Window.
 	 */
 	public Requisition getSize() {
+        checkState();
 		int [] width = new int[1];
 		int [] height = new int[1];
 		Window.gtk_window_get_size(getHandle(), width, height);
@@ -304,6 +330,7 @@ public class Window extends Bin {
 	 * @return The position of the window.
 	 */
 	public Point getPosition() {
+        checkState();
 		int [] x = new int[1];
 		int [] y = new int[1];
 		Window.gtk_window_get_position(getHandle(), x, y);
@@ -320,6 +347,7 @@ public class Window extends Bin {
 	 * @param y The y coordinate for the move.
 	 */
 	public void move(int x, int y) {
+        checkState();
 		Window.gtk_window_move(getHandle(), x, y);
 	}
 	
@@ -331,6 +359,7 @@ public class Window extends Bin {
 	 * @param height The height for the resized Window.
 	 */
 	public void resize(int width, int height) {
+        checkState();
 		Window.gtk_window_resize(getHandle(), width, height);
 	}
 	
@@ -341,6 +370,7 @@ public class Window extends Bin {
 	 * @param icon The Icon to use for this Window.
 	 */
 	public void setIcon(Pixbuf icon) {
+        checkState();
 		Window.gtk_window_set_icon(getHandle(), icon.getHandle());
 	}
 	
@@ -348,11 +378,9 @@ public class Window extends Bin {
 	 * Returns the icon representing the Window.
 	 */
 	public Pixbuf getIcon() {
+        checkState();
 		Handle hndl = gtk_window_get_icon(getHandle());
-		GObject obj = getGObjectFromHandle(hndl);
-		if (null != obj)
-			return (Pixbuf)obj;
-		return new Pixbuf(hndl);
+		return Pixbuf.getPixbufFromHandle(hndl);
 		
 	}
 	
@@ -376,6 +404,7 @@ public class Window extends Bin {
 	 * and larger images (64x64, 128x128) if you have them.
 	 */
 	public void setIconList(Pixbuf[] icons) {
+        checkState();
 		Handle[] hndls = new Handle[icons.length];
 		for (int i = 0; i < icons.length; i++)
 			hndls[i] = icons[i].getHandle();
@@ -387,12 +416,13 @@ public class Window extends Bin {
 	 * copied, but the reference count on each member won't be incremented.
 	 */
 	public Pixbuf[] getIconList() {
+        checkState();
 		Handle[] hndls = gtk_window_get_icon_list(getHandle());
 		if (hndls == null)
 			return null;
 		Pixbuf[] pix = new Pixbuf[hndls.length];
 		for (int i = 0; i < hndls.length; i++) 
-			pix[i] = new Pixbuf(hndls[i]);
+			pix[i] = Pixbuf.getPixbufFromHandle(hndls[i]);
 		return pix;
 	}
 
@@ -401,6 +431,7 @@ public class Window extends Bin {
 	 * @param skipHint
 	 */
 	public void setSkipTaskbarHint(boolean skipHint) {
+        checkState();
 		gtk_window_set_skip_taskbar_hint(getHandle(), skipHint);
 	}
 	
@@ -408,6 +439,7 @@ public class Window extends Bin {
 	 * Returns whether this window should appear in the task bar.
 	 */
 	public boolean getSkipTaskbarHint() {
+        checkState();
 		return gtk_window_get_skip_taskbar_hint(getHandle());
 	}
 	
@@ -416,6 +448,7 @@ public class Window extends Bin {
 	 * @param skipHint
 	 */
 	public void setSkipPagerHint(boolean skipHint) {
+        checkState();
 		gtk_window_set_skip_pager_hint(getHandle(), skipHint);
 	}
 
@@ -423,14 +456,17 @@ public class Window extends Bin {
 	 * Returns whether the window should appear in the pager.
 	 */
 	public boolean getSkipPagerHint() {
+        checkState();
 		return gtk_window_get_skip_pager_hint(getHandle());
 	}
 	
 	public void setAcceptFocus(boolean acceptFocus) {
+        checkState();
 		gtk_window_set_accept_focus(getHandle(), acceptFocus);
 	}
 	
 	public boolean getAcceptFocus() {
+        checkState();
 		return gtk_window_get_accept_focus(getHandle());
 	}
 	
@@ -441,6 +477,7 @@ public class Window extends Bin {
 	 */
 
 	public void setScreen(Screen screen) {
+        checkState();
 		gtk_window_set_screen(getHandle(), screen.getHandle());
 	}
 	
@@ -449,11 +486,9 @@ public class Window extends Bin {
 	 */
 
 	public Screen getScreen() {
+        checkState();
 	    Handle hndl = gtk_window_get_screen(getHandle());
-		GObject obj = getGObjectFromHandle(hndl);
-		if (null != obj)
-			return (Screen)obj;
-		return new Screen(hndl);
+		return Screen.getScreenFromHandle(hndl);
 	}
 	
 	/**
@@ -467,6 +502,7 @@ public class Window extends Bin {
 	 */
 
 	public boolean isActive() {
+        checkState();
 		return gtk_window_is_active(getHandle());
 	}
 	
@@ -477,6 +513,7 @@ public class Window extends Bin {
 	 */
 	
 	public boolean hasToplevelFocus() {
+        checkState();
 		return gtk_window_has_toplevel_focus(getHandle());
 	}
 
@@ -489,6 +526,7 @@ public class Window extends Bin {
 	 */
 	
 	public boolean setIconFromFile(String filename) {
+        checkState();
 		return gtk_window_set_icon_from_file(getHandle(), filename);
 	}
 	
@@ -516,18 +554,22 @@ public class Window extends Bin {
 	}
 	
 	public void fullscreen() {
+        checkState();
 		gtk_window_fullscreen(getHandle());
 	}
 	
 	public void unfullscreen() {
+        checkState();
 		gtk_window_unfullscreen(getHandle());
 	}
 	
 	public void setKeepAbove(boolean setting) {
+        checkState();
 		gtk_window_set_keep_above(getHandle(), setting);
 	}
 	
 	public void setKeepBelow(boolean setting) {
+        checkState();
 		gtk_window_set_keep_below(getHandle(), setting);
 	}
 	
@@ -575,7 +617,7 @@ public class Window extends Bin {
 	    Handle[] hndls = gtk_window_get_default_icon_list();
 		Pixbuf[] pbs = new Pixbuf[hndls.length];
 		for (int i = 0; i < hndls.length; i++) {
-			pbs[i] = new Pixbuf(hndls[i]);
+			pbs[i] = Pixbuf.getPixbufFromHandle(hndls[i]);
 		}
 		return pbs;
 	}
@@ -602,6 +644,7 @@ public class Window extends Bin {
      * @param setting TRUE to let this window receive input focus on map.
      */
     public void setFocusOnMap( boolean setting ) {
+        checkState();
         gtk_window_set_focus_on_map( getHandle(), setting );
     }
     /**
@@ -610,6 +653,7 @@ public class Window extends Bin {
      * @return TRUE if window should receive the input focus when mapped.
      */
     public boolean getFocusOnMap() {
+        checkState();
         return gtk_window_get_focus_on_map( getHandle() );
     }
 
@@ -623,6 +667,7 @@ public class Window extends Bin {
      * @param name The name of the themed icon.
      */
     public void setIconName( String name ) {
+        checkState();
         gtk_window_set_icon_name( getHandle(), name );
     }
     /**
@@ -631,6 +676,7 @@ public class Window extends Bin {
      * @return The icon name or NULL if the window has no themed icon.
      */
     public String getIconName() {
+        checkState();
         return gtk_window_get_icon_name( getHandle() );
     }
     
@@ -641,6 +687,7 @@ public class Window extends Bin {
      * @see #setIconName(String)
      */
     public void setDefaultIconName( String name ) {
+        checkState();
         gtk_window_set_default_icon_name( name );
     }
 	
@@ -651,6 +698,7 @@ public class Window extends Bin {
 	 * @see #setTransientParent(Window)
 	 */
 	public Window getTransientParent() {
+        checkState();
 		Handle handle = gtk_window_get_transient_for(getHandle());
 		return Window.getWindow(handle);
 	}
@@ -666,6 +714,7 @@ public class Window extends Bin {
 	 *            Transient parent window.
 	 */
 	public void setTransientParent(Window parent) {
+        checkState();
 		Handle parentHandle;
 		if (parent == null) {
 			parentHandle = getNullHandle();
@@ -682,6 +731,45 @@ public class Window extends Bin {
 	public static Type getType() {
 		return new Type(gtk_window_get_type());
 	}
+    
+    /**
+     * Destroys a window and releases its native resources. When a window is
+     * destroyed, it will break any references it holds to other objects and
+     * it will be removed from the list of toplevels. It is safe to call this
+     * method multiple times (the native resources will only be released once).
+     * However, no other methods on a window should be called after destroy
+     * is called. An ObjectDestroyedException is thrown if this takes place.
+     * 
+     * @see ObjectDestroyedException
+     */
+    public void destroy() {
+        if (isDestroyed()) {
+            return;
+        }
+        gtk_window_destroy(getHandle());
+        destroyed = true;
+    }
+    
+    /**
+     * Checks if the object has been destroyed and throws
+     * ObjectDestroyedException if this is the case.
+     */
+    protected void checkState() {
+        if (isDestroyed()) {
+            throw new ObjectDestroyedException();
+        }
+    }
+    
+    /**
+     * Returns true if destroy has previously been called on this object.
+     */
+    public boolean isDestroyed() {
+        return destroyed;
+    }
+    
+    // Override finalize as we don't want automatic collection to take place
+    // here
+    protected void finalize() {}
 
 	native static final protected int gtk_window_get_type();
 	native static final protected Handle gtk_window_new(int type);
@@ -770,4 +858,6 @@ public class Window extends Bin {
     native static final private void gtk_window_set_icon_name(Handle window, String name);
     native static final private String gtk_window_get_icon_name(Handle window);
     native static final private void gtk_window_set_default_icon_name(String name);
+    
+    native static final private void gtk_window_destroy(Handle window);
 }
