@@ -14,6 +14,8 @@
 
 package org.gnu.gtk.event;
 
+import org.gnu.glib.EventType;
+
 /**
  * This is an event for the toggling of {@link org.gnu.gtk.ToggleButton}
  * widgets.
@@ -22,7 +24,7 @@ package org.gnu.gtk.event;
  */
 public class ToggleEvent extends GtkEvent {
 
-	public static class Type extends GtkEventType {
+	public static class Type extends EventType {
 	    private Type(int id, String name){
 		super(id, name);
 	    }
