@@ -10,6 +10,7 @@
 #include <jni.h>
 #include <atk/atk.h>
 #include "jg_jnu.h"
+#include "gtk_java.h"
 
 #ifdef __cplusplus
 extern "C" 
@@ -33,7 +34,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_atk_RelationSet_atk_1relation_1set_1get_1typ
 JNIEXPORT jobject JNICALL Java_org_gnu_atk_RelationSet_atk_1relation_1set_1new (JNIEnv *env, 
     jclass cls) 
 {
-    return getHandleFromPointer(env, atk_relation_set_new ());
+    return getGObjectHandle(env, G_OBJECT(atk_relation_set_new ()));
 }
 
 /*
@@ -93,7 +94,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_atk_RelationSet_atk_1relation_1set_1get_1
 {
     AtkRelationSet *set_g = (AtkRelationSet *)getPointerFromHandle(env, set);
     gint32 index_g = (gint32) index;
-    return getHandleFromPointer(env, atk_relation_set_get_relation (set_g, index_g));
+    return getGObjectHandle(env, G_OBJECT(atk_relation_set_get_relation (set_g, index_g)));
 }
 
 /*
@@ -105,10 +106,23 @@ JNIEXPORT jobject JNICALL Java_org_gnu_atk_RelationSet_atk_1relation_1set_1get_1
 {
     AtkRelationSet *set_g = (AtkRelationSet *)getPointerFromHandle(env, set);
     AtkRelationType relationship_g = (AtkRelationType) relationship;
-    return getHandleFromPointer(env, atk_relation_set_get_relation_by_type (set_g, relationship_g));
+    return getGObjectHandle(env, G_OBJECT(atk_relation_set_get_relation_by_type (set_g, relationship_g)));
 }
 
 
+/*
+ * Class:     org_gnu_atk_RelationSet
+ * Method:    atk_relation_set_add_relation_by_type
+ */
+JNIEXPORT void JNICALL Java_org_gnu_atk_RelationSet_atk_1relation_1set_1add_1relation_1by_1type
+  (JNIEnv *env, jclass cls, jobject set, jint relationship, jobject target)
+{
+    AtkRelationSet *set_g = (AtkRelationSet *)getPointerFromHandle(env, set);
+    AtkRelationType relationship_g = (AtkRelationType) relationship;
+    AtkObject *target_g = (AtkObject *)getPointerFromHandle(env, target);
+    atk_relation_set_add_relation_by_type(set_g, relationship_g, target_g);
+}
+
 #ifdef __cplusplus
 }
 
