@@ -10,34 +10,13 @@
 #include <jni.h>
 #include <sys/types.h>
 #include <gdk/gdk.h>
-#include "jg_jnu.h"
+#include "gtk_java.h"
 
 #ifdef __cplusplus
 extern "C" 
 {
 #endif
 
-
-GdkEventType GdkEventFocus_get_type (GdkEventFocus * cptr) 
-{
-    return cptr->type;
-}
-
-/*
- * Class:     org.gnu.gdk.EventFocus
- * Method:    getType
- */
-JNIEXPORT jint JNICALL Java_org_gnu_gdk_EventFocus_getType (JNIEnv *env, jclass cls, jobject obj) 
-{
-    GdkEventFocus *obj_g = (GdkEventFocus *)getPointerFromHandle(env, obj);
-    return (jint) (GdkEventFocus_get_type (obj_g));
-}
-
-GdkWindow * GdkEventFocus_get_window (GdkEventFocus * cptr) 
-{
-    return cptr->window;
-}
-
 /*
  * Class:     org.gnu.gdk.EventFocus
  * Method:    getWindow
@@ -45,12 +24,7 @@ GdkWindow * GdkEventFocus_get_window (GdkEventFocus * cptr)
 JNIEXPORT jobject JNICALL Java_org_gnu_gdk_EventFocus_getWindow (JNIEnv *env, jclass cls, jobject obj)
 {
     GdkEventFocus *obj_g = (GdkEventFocus *)getPointerFromHandle(env, obj);
-    return getHandleFromPointer(env, GdkEventFocus_get_window (obj_g));
-}
-
-gboolean GdkEventFocus_get_send_event (GdkEventFocus * cptr) 
-{
-    return cptr->send_event;
+    return getGObjectHandle(env, (GObject *)obj_g);
 }
 
 /*
@@ -61,12 +35,7 @@ JNIEXPORT jboolean JNICALL Java_org_gnu_gdk_EventFocus_getSendEvent (JNIEnv *env
     jobject obj) 
 {
     GdkEventFocus *obj_g = (GdkEventFocus *)getPointerFromHandle(env, obj);
-    return (jboolean) (GdkEventFocus_get_send_event (obj_g));
-}
-
-gint32 GdkEventFocus_get_in (GdkEventFocus * cptr) 
-{
-    return cptr->in;
+    return (jboolean) obj_g->send_event;
 }
 
 /*
@@ -76,7 +45,7 @@ gint32 GdkEventFocus_get_in (GdkEventFocus * cptr)
 JNIEXPORT jint JNICALL Java_org_gnu_gdk_EventFocus_getIn (JNIEnv *env, jclass cls, jobject obj) 
 {
     GdkEventFocus *obj_g = (GdkEventFocus *)getPointerFromHandle(env, obj);
-    return (jint) (GdkEventFocus_get_in (obj_g));
+    return (jint) obj_g->in;
 }
 
 #ifdef __cplusplus
