@@ -18,6 +18,13 @@
 extern "C" {
 #endif
 
+JNIEXPORT void JNICALL Java_org_gnu_glib_MemStruct_init
+  (JNIEnv *env, jclass cls)
+{
+	initMemoryManagement();
+    jg_atexit((GVoidFunc) processPendingStruct);
+}
+   
 JNIEXPORT void JNICALL Java_org_gnu_glib_MemStruct_nativeFinalize
   (JNIEnv *env, jclass cls, jobject handle)
 {
