@@ -151,7 +151,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gtk_Box_gtk_1box_1query_1child_1packing (JNI
     GtkWidget *child_g = (GtkWidget *)getPointerFromHandle(env, child);
     gboolean *expand_g = (gboolean *) (*env)->GetBooleanArrayElements(env, expand, NULL);
     gboolean *fill_g = (gboolean *) (*env)->GetBooleanArrayElements(env, fill, NULL);
-    gint *padding_g = (gint *) (*env)->GetIntArrayElements (env, padding, NULL);
+    guint *padding_g = (guint *) (*env)->GetIntArrayElements (env, padding, NULL);
     gint *packType_g_g = (gint *) (*env)->GetIntArrayElements (env, packType, NULL);
     GtkPackType *packType_g = (GtkPackType *)packType_g_g;
     gtk_box_query_child_packing (box_g, child_g, expand_g, fill_g, padding_g, packType_g);
