@@ -9,7 +9,8 @@
 
 #include <jni.h>
 #include <gtk/gtk.h>
-#include "jg_jnu.h"
+#include <jg_jnu.h>
+#include "gtk_java.h"
 
 #ifdef __cplusplus
 extern "C" 
@@ -31,7 +32,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gtk_Button_gtk_1button_1get_1type (JNIEnv *e
  */
 JNIEXPORT jobject JNICALL Java_org_gnu_gtk_Button_gtk_1button_1new (JNIEnv *env, jclass cls) 
 {
-    return getHandleFromPointer(env, gtk_button_new ());
+	return getGObjectHandle(env, (GObject*) gtk_button_new());
 }
 
 /*
@@ -42,7 +43,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_Button_gtk_1button_1new_1with_1label
     jclass cls, jstring label) 
 {
     const gchar* label_g = (*env)->GetStringUTFChars( env, label, NULL);
-    jobject retval =  getHandleFromPointer(env, gtk_button_new_with_label (label_g));
+    jobject retval =  getGObjectHandle(env, (GObject *) gtk_button_new_with_label (label_g));
 	(*env)->ReleaseStringUTFChars(env, label, label_g);
 	return retval;
 }
@@ -55,7 +56,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_Button_gtk_1button_1new_1from_1stock
     jclass cls, jstring stock_id) 
 {
     const gchar* stock_id_g = (*env)->GetStringUTFChars(env, stock_id, NULL);
-     jobject retval = getHandleFromPointer(env, gtk_button_new_from_stock (stock_id_g));
+     jobject retval = getGObjectHandle(env, (GObject *) gtk_button_new_from_stock (stock_id_g));
 	 (*env)->ReleaseStringUTFChars(env, stock_id, stock_id_g);
 	 return retval;
 }
@@ -68,7 +69,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_Button_gtk_1button_1new_1with_1mnemon
     jclass cls, jstring label) 
 {
     const gchar* label_g = (*env)->GetStringUTFChars(env, label, NULL);
-	jobject retval = getHandleFromPointer(env, gtk_button_new_with_mnemonic (label_g));
+	jobject retval = getGObjectHandle(env, (GObject *) gtk_button_new_with_mnemonic (label_g));
 	(*env)->ReleaseStringUTFChars( env, label, label_g );
 	return retval;
 }
@@ -289,7 +290,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_Button_gtk_1button_1get_1image
   (JNIEnv *env, jclass cls, jobject button)
 {
     GtkButton *button_g = (GtkButton *)getPointerFromHandle(env, button);
-    return getHandleFromPointer(env, gtk_button_get_image(button_g));
+    return getGObjectHandle(env, (GObject *) gtk_button_get_image(button_g));
 }
 
 
