@@ -9,7 +9,8 @@
 
 #include <jni.h>
 #include <gtk/gtk.h>
-#include "jg_jnu.h"
+#include <jg_jnu.h>
+#include "gtk_java.h"
 
 #ifndef _Included_org_gnu_gtk_ComboBox
 #define _Included_org_gnu_gtk_ComboBox
@@ -34,7 +35,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gtk_ComboBox_gtk_1combo_1box_1get_1type
 JNIEXPORT jobject JNICALL Java_org_gnu_gtk_ComboBox_gtk_1combo_1box_1new
   (JNIEnv *env, jclass cls)
 {
-	return getHandleFromPointer(env, gtk_combo_box_new());
+	return getGObjectHandle(env, (GObject *) gtk_combo_box_new());
 }
 
 /*
@@ -45,7 +46,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_ComboBox_gtk_1combo_1box_1new_1with_1
   (JNIEnv *env, jclass cls, jobject model)
 {
 	GtkTreeModel* model_g = (GtkTreeModel*)getPointerFromHandle(env, model);
-	return getHandleFromPointer(env, gtk_combo_box_new_with_model(model_g));
+	return getGObjectHandle(env, (GObject *) gtk_combo_box_new_with_model(model_g));
 }
 
 /*  
@@ -184,20 +185,23 @@ JNIEXPORT void JNICALL Java_org_gnu_gtk_ComboBox_gtk_1combo_1box_1set_1active
  * Class:     org_gnu_gtk_ComboBox
  * Method:    gtk_combo_box_get_active_iter
  */
-JNIEXPORT jboolean JNICALL Java_org_gnu_gtk_ComboBox_gtk_1combo_1box_1get_1active_1iter
-  (JNIEnv *env, jclass cls, jobject combo, jobject iter)
+JNIEXPORT jobject JNICALL Java_org_gnu_gtk_ComboBox_gtk_1combo_1box_1get_1active_1iter
+  (JNIEnv *env, jclass cls, jobject combo)
 {
-	GtkComboBox* combo_g = (GtkComboBox*)getPointerFromHandle(env, combo);
-	GtkTreeIter* iter_g = (GtkTreeIter*)getPointerFromHandle(env, iter);
-        gboolean ret_g;
-        if ( !iter_g ) {
-            iter_g = g_new( GtkTreeIter, 1 );
-            ret_g = gtk_combo_box_get_active_iter(combo_g, iter_g);
-            updateHandle(env, iter, iter_g);
-        } else {
-            ret_g = gtk_combo_box_get_active_iter(combo_g, iter_g);
-        }
-	return (jboolean)ret_g;
+	GtkComboBox *combo_g;
+	GtkTreeIter *iter_g;
+	gboolean ret_g;
+	combo_g = (GtkComboBox*)getPointerFromHandle(env, combo);
+    iter_g = g_new( GtkTreeIter, 1 );
+    ret_g = gtk_combo_box_get_active_iter(combo_g, iter_g);
+    if (ret_g)	{
+    	return getGBoxedHandle(env, iter_g, GTK_TYPE_TREE_ITER, NULL,
+        		(GBoxedFreeFunc) gtk_tree_iter_free);
+    }
+    else	{
+    	gtk_tree_iter_free(iter_g);
+    	return NULL;
+    }
 }
 
 /*
@@ -232,7 +236,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_ComboBox_gtk_1combo_1box_1get_1model
   (JNIEnv *env, jclass cls, jobject combo)
 {
 	GtkComboBox* combo_g = (GtkComboBox*)getPointerFromHandle(env, combo);
-	return getHandleFromPointer(env, gtk_combo_box_get_model(combo_g));
+	return getGObjectHandle(env, (GObject *) gtk_combo_box_get_model(combo_g));
 }
 
 /*
@@ -242,7 +246,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_ComboBox_gtk_1combo_1box_1get_1model
 JNIEXPORT jobject JNICALL Java_org_gnu_gtk_ComboBox_gtk_1combo_1box_1new_1text
   (JNIEnv *env, jclass cls)
 {
-	return getHandleFromPointer(env, gtk_combo_box_new_text());
+	return getGObjectHandle(env, (GObject *) gtk_combo_box_new_text());
 }
 
 /*
@@ -337,20 +341,21 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_ComboBox_gtk_1combo_1box_1get_1popup_
   (JNIEnv *env, jclass cls, jobject combo)
 {
 	GtkComboBox* combo_g = (GtkComboBox*)getPointerFromHandle(env, combo);
-	return getHandleFromPointer(env, gtk_combo_box_get_popup_accessible(combo_g));
+	return getGObjectHandle(env, (GObject *) gtk_combo_box_get_popup_accessible(combo_g));
 }
 
 gboolean static treeViewRowSeparatorFunc( GtkTreeModel *model, 
                                           GtkTreeIter *iter, 
                                           gpointer data ) {
-	JGFuncCallbackRef *ref = (JGFuncCallbackRef*) data;
-	return (* ref->env)->CallBooleanMethod(ref->env, 
-                                               ref->obj, 
-                                               ref->methodID,
-                                               getHandleFromPointer(ref->env,
-                                                                    model),
-                                               getHandleFromPointer(ref->env,
-                                                                    iter) );
+    jobject modelHandle;
+    jobject iterHandle;
+	JGFuncCallbackRef *ref;
+	ref = (JGFuncCallbackRef*) data;
+	modelHandle = getGObjectHandle(ref->env, (GObject *) model);
+	iterHandle = getGBoxedHandle(ref->env, iter, GTK_TYPE_TREE_ITER, NULL,
+			(GBoxedFreeFunc) gtk_tree_iter_free);
+	return (* ref->env)->CallBooleanMethod(ref->env, ref->obj, ref->methodID,
+			modelHandle, iterHandle);
 }
 
 JNIEXPORT void JNICALL Java_org_gnu_gtk_ComboBox_gtk_1combo_1box_1set_1row_1separator_1func
