@@ -9,7 +9,8 @@
 
 #include <jni.h>
 #include <gtk/gtk.h>
-#include "jg_jnu.h"
+#include <jg_jnu.h>
+#include "gtk_java.h"
 
 #ifndef _Included_org_gnu_gtk_Expander
 #define _Included_org_gnu_gtk_Expander
@@ -35,7 +36,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_Expander_gtk_1expander_1new
   (JNIEnv *env, jclass cls, jstring label)
 {
 	const gchar* l = (*env)->GetStringUTFChars(env, label, NULL);
-	jobject ret = getHandleFromPointer(env, gtk_expander_new(l));
+	jobject ret = getGObjectHandle(env, (GObject *) gtk_expander_new(l));
 	(*env)->ReleaseStringUTFChars(env, label, l);
 	return ret;
 }
@@ -48,7 +49,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_Expander_gtk_1expander_1new_1with_1mn
   (JNIEnv *env, jclass cls, jstring label)
 {
 	const gchar* l = (*env)->GetStringUTFChars(env, label, NULL);
-	jobject ret = getHandleFromPointer(env, gtk_expander_new_with_mnemonic(l));
+	jobject ret = getGObjectHandle(env, (GObject *) gtk_expander_new_with_mnemonic(l));
 	(*env)->ReleaseStringUTFChars(env, label, l);
 	return ret;
 }
@@ -187,7 +188,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_Expander_gtk_1expander_1get_1label_1w
   (JNIEnv *env, jclass cls, jobject expander)
 {
 	GtkExpander* expander_g = (GtkExpander*)getPointerFromHandle(env, expander);
-	return getHandleFromPointer(env, gtk_expander_get_label_widget(expander_g));
+	return getGObjectHandle(env, (GObject *) gtk_expander_get_label_widget(expander_g));
 }
 
 #ifdef __cplusplus
