@@ -9,7 +9,8 @@
 
 #include <jni.h>
 #include <gtk/gtk.h>
-#include "jg_jnu.h"
+#include <jg_jnu.h>
+#include "gtk_java.h"
 
 #ifdef __cplusplus
 extern "C" 
@@ -31,7 +32,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gtk_HPaned_gtk_1hpaned_1get_1type (JNIEnv *e
  */
 JNIEXPORT jobject JNICALL Java_org_gnu_gtk_HPaned_gtk_1hpaned_1new (JNIEnv *env, jclass cls) 
 {
-    return getHandleFromPointer(env, gtk_hpaned_new ());
+    return getGObjectHandle(env, (GObject *) gtk_hpaned_new ());
 }
 
 #ifdef __cplusplus
