@@ -9,7 +9,8 @@
 
 #include <jni.h>
 #include <gtk/gtk.h>
-#include "jg_jnu.h"
+#include <jg_jnu.h>
+#include "gtk_java.h"
 
 #ifdef __cplusplus
 extern "C" 
@@ -33,7 +34,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gtk_ImageMenuItem_gtk_1image_1menu_1item_1ge
 JNIEXPORT jobject JNICALL Java_org_gnu_gtk_ImageMenuItem_gtk_1image_1menu_1item_1new (JNIEnv *env, 
     jclass cls) 
 {
-    return getHandleFromPointer(env, gtk_image_menu_item_new ());
+    return getGObjectHandle(env, (GObject *) gtk_image_menu_item_new ());
 }
 
 /*
@@ -44,7 +45,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_ImageMenuItem_gtk_1image_1menu_1item_
     JNIEnv *env, jclass cls, jstring label) 
 {
     gchar* label_g = (gchar*)(*env)->GetStringUTFChars(env, label, 0);
-    jobject result = getHandleFromPointer(env, gtk_image_menu_item_new_with_label (label_g));
+    jobject result = getGObjectHandle(env, (GObject *) gtk_image_menu_item_new_with_label (label_g));
     (*env)->ReleaseStringUTFChars(env, label, label_g);
     return result;
 }
@@ -58,7 +59,8 @@ Java_org_gnu_gtk_ImageMenuItem_gtk_1image_1menu_1item_1new_1with_1mnemonic (JNIE
     cls, jstring label) 
 {
     gchar* label_g = (gchar*)(*env)->GetStringUTFChars(env, label, 0);
-    jobject result = getHandleFromPointer(env, gtk_image_menu_item_new_with_mnemonic (label_g));
+    jobject result = getGObjectHandle(env, (GObject *)
+    		gtk_image_menu_item_new_with_mnemonic (label_g));
     (*env)->ReleaseStringUTFChars(env, label, label_g);
     return result;
 }
@@ -72,7 +74,8 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_ImageMenuItem_gtk_1image_1menu_1item_
 {
     gchar* stockId_g = (gchar*)(*env)->GetStringUTFChars(env, stockId, 0);
     GtkAccelGroup *accelGroup_g = (GtkAccelGroup *)getPointerFromHandle(env, accelGroup);
-    jobject result = getHandleFromPointer(env, gtk_image_menu_item_new_from_stock (stockId_g, accelGroup_g));
+    jobject result = getGObjectHandle(env, (GObject *)
+    		gtk_image_menu_item_new_from_stock (stockId_g, accelGroup_g));
     (*env)->ReleaseStringUTFChars(env, stockId, stockId_g);
     return result;
 }
@@ -96,8 +99,9 @@ JNIEXPORT void JNICALL Java_org_gnu_gtk_ImageMenuItem_gtk_1image_1menu_1item_1se
 JNIEXPORT jobject JNICALL Java_org_gnu_gtk_ImageMenuItem_gtk_1image_1menu_1item_1get_1image (
     JNIEnv *env, jclass cls, jobject image_menu_item) 
 {
-    GtkImageMenuItem *image_menu_item_g = (GtkImageMenuItem *)getPointerFromHandle(env, image_menu_item);
-    return getHandleFromPointer(env, gtk_image_menu_item_get_image (image_menu_item_g));
+    GtkImageMenuItem *image_menu_item_g = (GtkImageMenuItem *)
+    		getPointerFromHandle(env, image_menu_item);
+    return getGObjectHandle(env, (GObject *) gtk_image_menu_item_get_image (image_menu_item_g));
 }
 
 
