@@ -10,13 +10,19 @@
 #include <jni.h>
 #include <sys/types.h>
 #include <gtk/gtk.h>
-#include "jg_jnu.h"
+#include <jg_jnu.h>
+#include "gtk_java.h"
 
 #ifdef __cplusplus
 extern "C" 
 {
 #endif
 
+static jobject getTextIter(JNIEnv* env, GtkTextIter* iter)
+{
+	return getGBoxedHandle(env, iter, 	GTK_TYPE_TEXT_ITER, (GBoxedCopyFunc)
+			gtk_text_iter_copy, (GBoxedFreeFunc) gtk_text_iter_free);	
+}
 /*
  * Class:     org.gnu.gtk.TextBuffer
  * Method:    gtk_text_buffer_get_type
@@ -36,7 +42,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1new (JN
 {
     GtkTextTagTable *table_g = 
         (GtkTextTagTable *)getPointerFromHandle(env, table);
-    return getHandleFromPointer(env, gtk_text_buffer_new (table_g));
+    return getGObjectHandle(env, (GObject *) gtk_text_buffer_new (table_g));
 }
 
 /*
@@ -72,7 +78,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1ta
 {
     GtkTextBuffer *buffer_g = 
         (GtkTextBuffer*)getPointerFromHandle(env, buffer);
-    return getHandleFromPointer(env, gtk_text_buffer_get_tag_table (buffer_g));
+    return getGObjectHandle(env, (GObject *) gtk_text_buffer_get_tag_table (buffer_g));
 }
 
 /*
@@ -310,7 +316,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1create_
         (GtkTextBuffer*)getPointerFromHandle(env, buffer);
     GtkTextIter *iter_g = (GtkTextIter*)getPointerFromHandle(env, iter);
     return 
-        getHandleFromPointer(env, 
+        getGObjectHandle(env, (GObject *)
                              gtk_text_buffer_create_child_anchor (buffer_g, 
                                                                   iter_g));
 }
@@ -332,7 +338,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1create_
                                                        (gboolean)leftGravity);
     g_assert(result != NULL);
     (*env)->ReleaseStringUTFChars(env, markName, utf);
-    return getHandleFromPointer(env, result);
+    return getGObjectHandleAndRef(env, (GObject *) result);
 }
 
 /*
@@ -376,7 +382,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1ma
     GtkTextMark *mark = gtk_text_buffer_get_mark (buffer_g, 
                                                   (gchar*)utf);
     (*env)->ReleaseStringUTFChars(env, name, utf);
-    return getHandleFromPointer(env, mark);
+    return getGObjectHandleAndRef(env, (GObject *) mark);
 }
 
 /*
@@ -418,7 +424,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1in
 {
     GtkTextBuffer *buffer_g = 
         (GtkTextBuffer*)getPointerFromHandle(env, buffer);
-    return getHandleFromPointer(env, gtk_text_buffer_get_insert (buffer_g));
+    return getGObjectHandle(env, (GObject *) gtk_text_buffer_get_insert (buffer_g));
 }
 
 /*
@@ -430,7 +436,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1se
 {
     GtkTextBuffer *buffer_g = 
         (GtkTextBuffer*)getPointerFromHandle(env, buffer);
-    return getHandleFromPointer(env, gtk_text_buffer_get_selection_bound (buffer_g));
+    return getGObjectHandle(env, (GObject *) gtk_text_buffer_get_selection_bound (buffer_g));
 }
 
 /*
@@ -831,14 +837,14 @@ JNIEXPORT void JNICALL Java_org_gnu_gtk_TextBuffer_insert_1with_1tag (JNIEnv *en
     (*env)->ReleaseStringUTFChars(env, tag, tag_g);
 }
 	
-JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_create_1tag ( JNIEnv *env, jclass cls, jobject buffer, jstring name )
+JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_create_1tag
+		(JNIEnv *env, jclass cls, jobject buffer, jstring name)
 {
     GtkTextBuffer *buffer_g = 
         (GtkTextBuffer*)getPointerFromHandle(env, buffer);
     const char *name_g = (*env)->GetStringUTFChars(env, name, NULL);
     jobject retval = 
-        getHandleFromPointer(env, 
-                             gtk_text_buffer_create_tag(buffer_g, 
+        getGObjectHandleAndRef(env, (GObject *) gtk_text_buffer_create_tag(buffer_g, 
                                                         name_g, NULL));
     (*env)->ReleaseStringUTFChars(env, name, name_g);
     return retval;
@@ -846,7 +852,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_create_1tag ( JNIEnv *env,
 	
 JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1new_1noTable (JNIEnv *env, jclass cls) 
 {
-    return getHandleFromPointer(env, gtk_text_buffer_new (NULL));
+    return getGObjectHandle(env, (GObject *) gtk_text_buffer_new (NULL));
 }
 
 JNIEXPORT jboolean JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1selection_1exists (JNIEnv *env, jclass cls, jobject buffer) 
@@ -856,27 +862,30 @@ JNIEXPORT jboolean JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1s
     return (jboolean)gtk_text_buffer_get_selection_bounds(buffer_g, NULL, NULL);
 }
     
-JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1selection_1start (JNIEnv *env, jclass cls, jobject buffer) 
+JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1selection_1start
+		(JNIEnv *env, jclass cls, jobject buffer) 
 {
     GtkTextBuffer *buffer_g = 
         (GtkTextBuffer*)getPointerFromHandle(env, buffer);
     GtkTextIter *start_g = (GtkTextIter *)g_malloc(sizeof(GtkTextIter));
     gtk_text_buffer_get_selection_bounds (buffer_g, 
                                           start_g, NULL);
-    return getHandleFromPointer(env, start_g);
+    return getTextIter(env, start_g);
 }
     
-JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1selection_1end (JNIEnv *env, jclass cls, jobject buffer) 
+JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1selection_1end
+		(JNIEnv *env, jclass cls, jobject buffer) 
 {
     GtkTextBuffer *buffer_g = 
         (GtkTextBuffer*)getPointerFromHandle(env, buffer);
     GtkTextIter *end_g = (GtkTextIter *)g_malloc(sizeof(GtkTextIter));
     gtk_text_buffer_get_selection_bounds (buffer_g, 
                                           NULL, end_g);
-    return getHandleFromPointer(env, end_g);
+    return getTextIter(env, end_g);
 }
 
-JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1iter_1at_1line_1offsetMOD (JNIEnv *env, jclass cls, jobject buffer, jint lineNumber, jint charOffset) 
+JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1iter_1at_1line_1offsetMOD
+		(JNIEnv *env, jclass cls, jobject buffer, jint lineNumber, jint charOffset) 
 {
     GtkTextBuffer *buffer_g = 
         (GtkTextBuffer*)getPointerFromHandle(env, buffer);
@@ -885,9 +894,10 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1it
                                              iter_g, 
                                              (gint32)lineNumber, 
                                              (gint32)charOffset);
-    return getHandleFromPointer(env, iter_g);
+    return getTextIter(env, iter_g);
 }
-JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1iter_1at_1offsetMOD (JNIEnv *env, jclass cls, jobject buffer, jint charOffset) 
+JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1iter_1at_1offsetMOD
+		(JNIEnv *env, jclass cls, jobject buffer, jint charOffset) 
 {
     GtkTextBuffer *buffer_g = 
         (GtkTextBuffer*)getPointerFromHandle(env, buffer);
@@ -895,21 +905,23 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1it
     gtk_text_buffer_get_iter_at_offset (buffer_g, 
                                         iter_g, 
                                         (gint32)charOffset);
-    return getHandleFromPointer(env, iter_g);
+    return getTextIter(env, iter_g);
 }
 
-JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1iter_1at_1lineMOD (JNIEnv *env, jclass cls, jobject buffer, jint lineNumber) 
+JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1iter_1at_1lineMOD
+		(JNIEnv *env, jclass cls, jobject buffer, jint lineNumber) 
 {
     GtkTextBuffer *buffer_g = 
         (GtkTextBuffer*)getPointerFromHandle(env, buffer);
-    GtkTextIter *iter_g = (GtkTextIter *) g_malloc(sizeof(GtkTextIter));
+    GtkTextIter iter_g;
     gtk_text_buffer_get_iter_at_line (buffer_g, 
-                                      iter_g, 
+                                      &iter_g, 
                                       (gint32)lineNumber);
-    return getHandleFromPointer(env, iter_g);
+    return getTextIter(env, &iter_g);
 }
 
-JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1iter_1at_1markMOD (JNIEnv *env, jclass cls, jobject buffer, jobject mark) 
+JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1iter_1at_1markMOD
+		(JNIEnv *env, jclass cls, jobject buffer, jobject mark) 
 {
     GtkTextBuffer *buffer_g = 
         (GtkTextBuffer*)getPointerFromHandle(env, buffer);
@@ -918,10 +930,11 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1it
     gtk_text_buffer_get_iter_at_mark (buffer_g, 
                                       iter_g, 
                                       mark_g);
-    return getHandleFromPointer(env, iter_g);
+    return getTextIter(env, iter_g);
 }
     
-JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1iter_1at_1child_1anchorMOD (JNIEnv *env, jclass cls, jobject buffer, jint anchor) 
+JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1iter_1at_1child_1anchorMOD
+		(JNIEnv *env, jclass cls, jobject buffer, jint anchor) 
 {
     GtkTextBuffer *buffer_g = 
         (GtkTextBuffer*)getPointerFromHandle(env, buffer);
@@ -929,28 +942,31 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1it
     gtk_text_buffer_get_iter_at_child_anchor (buffer_g, 
                                               iter_g, 
                                               (GtkTextChildAnchor*)anchor);
-    return getHandleFromPointer(env, iter_g);
+    return getTextIter(env, iter_g);
 }
 
-JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1start_1iterMOD (JNIEnv *env, jclass cls, jobject buffer) 
+JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1start_1iterMOD
+		(JNIEnv *env, jclass cls, jobject buffer) 
 {
     GtkTextBuffer *buffer_g = 
         (GtkTextBuffer*)getPointerFromHandle(env, buffer);
     GtkTextIter *iter_g = (GtkTextIter *)g_malloc(sizeof(GtkTextIter));
     gtk_text_buffer_get_start_iter (buffer_g, iter_g);
-    return getHandleFromPointer(env, iter_g);
+    return getTextIter(env, iter_g);
 }
 
-JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1end_1iterMOD (JNIEnv *env, jclass cls, jobject buffer) 
+JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1end_1iterMOD
+		(JNIEnv *env, jclass cls, jobject buffer) 
 {
     GtkTextBuffer *buffer_g = 
         (GtkTextBuffer*)getPointerFromHandle(env, buffer);
     GtkTextIter *iter_g = (GtkTextIter *)g_malloc(sizeof(GtkTextIter));
     gtk_text_buffer_get_end_iter (buffer_g, iter_g);
-    return getHandleFromPointer(env, iter_g);
+    return getTextIter(env, iter_g);
 }
 
-JNIEXPORT void JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1paste_1clipboardInsertPosisition (JNIEnv *env, jclass cls, jobject buffer, jobject clipboard, jboolean defaultEditable) 
+JNIEXPORT void JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1paste_1clipboardInsertPosisition
+		(JNIEnv *env, jclass cls, jobject buffer, jobject clipboard, jboolean defaultEditable) 
 {
     GtkTextBuffer *buffer_g = 
         (GtkTextBuffer*)getPointerFromHandle(env, buffer);
