@@ -10,7 +10,8 @@
 #include <jni.h>
 #include <sys/types.h>
 #include <gtk/gtk.h>
-#include "jg_jnu.h"
+#include <jg_jnu.h>
+#include "gtk_java.h"
 
 #ifdef __cplusplus
 extern "C" 
@@ -26,7 +27,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextView_getHAdjustment
 {
     GtkTextView *textView_g = 
         (GtkTextView *)getPointerFromHandle(env, textView);
-	return getHandleFromPointer(env, textView_g->hadjustment);
+	return getGObjectHandle(env, (GObject *) textView_g->hadjustment);
 }
 
 /*
@@ -38,7 +39,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextView_getVAdjustment
 {
     GtkTextView *textView_g = 
         (GtkTextView *)getPointerFromHandle(env, textView);
-    return getHandleFromPointer(env, textView_g->vadjustment);
+    return getGObjectHandle(env, (GObject *) textView_g->vadjustment);
 }
 
 /*
@@ -58,7 +59,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gtk_TextView_gtk_1text_1view_1get_1type (JNI
  */
 JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextView_gtk_1text_1view_1new (JNIEnv *env, jclass cls) 
 {
-    return getHandleFromPointer(env, gtk_text_view_new ());
+    return getGObjectHandle(env, (GObject *) gtk_text_view_new ());
 }
 
 /*
@@ -70,7 +71,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextView_gtk_1text_1view_1new_1with_1
 {
     GtkTextBuffer *buffer_g = 
         (GtkTextBuffer *)getPointerFromHandle(env, buffer);
-    return getHandleFromPointer(env, gtk_text_view_new_with_buffer (buffer_g));
+    return getGObjectHandle(env, (GObject *) gtk_text_view_new_with_buffer (buffer_g));
 }
 
 /*
@@ -96,7 +97,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextView_gtk_1text_1view_1get_1buffer
 {
     GtkTextView *textView_g = 
         (GtkTextView *)getPointerFromHandle(env, textView);
-    return getHandleFromPointer(env, gtk_text_view_get_buffer (textView_g));
+    return getGObjectHandle(env, (GObject *) gtk_text_view_get_buffer (textView_g));
 }
 
 /*
@@ -177,13 +178,16 @@ JNIEXPORT jboolean JNICALL Java_org_gnu_gtk_TextView_gtk_1text_1view_1place_1cur
  * Method:    gtk_text_view_get_visible_rect
  * Signature: (II)V
  */
-JNIEXPORT void JNICALL Java_org_gnu_gtk_TextView_gtk_1text_1view_1get_1visible_1rect (JNIEnv *env, jclass cls, jobject textView, jobject visibleRect) 
+JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextView_gtk_1text_1view_1get_1visible_1rect
+(JNIEnv *env, jclass cls, jobject textView) 
 {
-    GtkTextView *textView_g = 
-        (GtkTextView *)getPointerFromHandle(env, textView);
-    GdkRectangle *visibleRect_g = 
-        (GdkRectangle *)getPointerFromHandle(env, visibleRect);
+    GtkTextView *textView_g;
+    GdkRectangle *visibleRect_g;
+    textView_g = (GtkTextView *)getPointerFromHandle(env, textView);
+    visibleRect_g = g_new(GdkRectangle, 1);
     gtk_text_view_get_visible_rect (textView_g, visibleRect_g);
+    return getGBoxedHandle(env, visibleRect_g, GDK_TYPE_RECTANGLE, NULL,
+    		(GBoxedFreeFunc) g_free);
 }
 
 /*
@@ -216,14 +220,18 @@ JNIEXPORT jboolean JNICALL Java_org_gnu_gtk_TextView_gtk_1text_1view_1get_1curso
  * Method:    gtk_text_view_get_iter_location
  * Signature: (III)V
  */
-JNIEXPORT void JNICALL Java_org_gnu_gtk_TextView_gtk_1text_1view_1get_1iter_1location (JNIEnv *env, jclass cls, jobject textView, jobject iter, jobject location) 
+JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextView_gtk_1text_1view_1get_1iter_1location
+(JNIEnv *env, jclass cls, jobject textView, jobject iter) 
 {
-    GtkTextView *textView_g = 
-        (GtkTextView *)getPointerFromHandle(env, textView);
-    GtkTextIter *iter_g = (GtkTextIter *)getPointerFromHandle(env, iter);
-    GdkRectangle *location_g = 
-        (GdkRectangle *)getPointerFromHandle(env, location);
+    GtkTextView *textView_g;
+    GtkTextIter *iter_g;
+    GdkRectangle *location_g;
+    textView_g = (GtkTextView *)getPointerFromHandle(env, textView);
+    iter_g = (GtkTextIter *)getPointerFromHandle(env, iter);
+    location_g = g_new(GdkRectangle, 1);
     gtk_text_view_get_iter_location (textView_g, iter_g, location_g);
+    return getGBoxedHandle(env, location_g, gdk_rectangle_get_type(), NULL, 
+    		(GBoxedFreeFunc) g_free);
 }
 
 /*
@@ -231,14 +239,19 @@ JNIEXPORT void JNICALL Java_org_gnu_gtk_TextView_gtk_1text_1view_1get_1iter_1loc
  * Method:    gtk_text_view_get_iter_at_location
  * Signature: (IIII)V
  */
-JNIEXPORT void JNICALL Java_org_gnu_gtk_TextView_gtk_1text_1view_1get_1iter_1at_1location (JNIEnv *env, jclass cls, jobject textView, jobject iter, jint x, jint y) 
+JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextView_gtk_1text_1view_1get_1iter_1at_1location
+(JNIEnv *env, jclass cls, jobject textView, jint x, jint y) 
 {
-    GtkTextView *textView_g = 
-        (GtkTextView *)getPointerFromHandle(env, textView);
-    GtkTextIter *iter_g = (GtkTextIter *)getPointerFromHandle(env, iter);
-    gint32 x_g = (gint32) x;
-    gint32 y_g = (gint32) y;
-    gtk_text_view_get_iter_at_location (textView_g, iter_g, x_g, y_g);
+    GtkTextView *textView_g;
+    GtkTextIter iter_g;
+    gint32 y_g;
+    gint32 x_g;
+    textView_g = (GtkTextView *)getPointerFromHandle(env, textView);
+    x_g = (gint32) x;
+    y_g = (gint32) y;
+    gtk_text_view_get_iter_at_location (textView_g, &iter_g, x_g, y_g);
+    getGBoxedHandle(env, &iter_g, gtk_text_iter_get_type(), 
+    		(GBoxedCopyFunc) gtk_text_iter_copy,  (GBoxedFreeFunc) gtk_text_iter_free);
 }
 
 /*
@@ -246,7 +259,8 @@ JNIEXPORT void JNICALL Java_org_gnu_gtk_TextView_gtk_1text_1view_1get_1iter_1at_
  * Method:    gtk_text_view_get_line_yrange
  * Signature: (II[Lint ;[Lint ;)V
  */
-JNIEXPORT void JNICALL Java_org_gnu_gtk_TextView_gtk_1text_1view_1get_1line_1yrange (JNIEnv *env, jclass cls, jobject textView, jobject iter, jintArray y, jintArray height) 
+JNIEXPORT void JNICALL Java_org_gnu_gtk_TextView_gtk_1text_1view_1get_1line_1yrange
+(JNIEnv *env, jclass cls, jobject textView, jobject iter, jintArray y, jintArray height) 
 {
     GtkTextView *textView_g = 
         (GtkTextView *)getPointerFromHandle(env, textView);
@@ -331,7 +345,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextView_gtk_1text_1view_1get_1window
     GtkTextView *textView_g = 
         (GtkTextView *)getPointerFromHandle(env, textView);
     GtkTextWindowType win_g = (GtkTextWindowType) win;
-    return getHandleFromPointer(env, gtk_text_view_get_window (textView_g, win_g));
+    return getGObjectHandle(env, (GObject *) gtk_text_view_get_window (textView_g, win_g));
 }
 
 /*
@@ -339,11 +353,12 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextView_gtk_1text_1view_1get_1window
  * Method:    gtk_text_view_get_window_type
  * Signature: (II)I
  */
-JNIEXPORT jint JNICALL Java_org_gnu_gtk_TextView_gtk_1text_1view_1get_1window_1type (JNIEnv *env, jclass cls, jobject textView, jobject window) 
+JNIEXPORT jint JNICALL Java_org_gnu_gtk_TextView_gtk_1text_1view_1get_1window_1type
+		(JNIEnv *env, jclass cls, jobject textView, jobject window) 
 {
     GtkTextView *textView_g = 
-        (GtkTextView *)getPointerFromHandle(env, textView);
-    GdkWindow *window_g = (GdkWindow *)window;
+    		(GtkTextView *) getPointerFromHandle(env, textView);
+    GdkWindow *window_g = (GdkWindow *) getPointerFromHandle(env, window);
     return (jint) (gtk_text_view_get_window_type (textView_g, window_g));
 }
 
@@ -745,11 +760,15 @@ JNIEXPORT void JNICALL Java_org_gnu_gtk_TextView_gtk_1text_1view_1set_1tabs (JNI
  * Method:    gtk_text_view_get_tabs
  * Signature: (I)I
  */
-JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextView_gtk_1text_1view_1get_1tabs (JNIEnv *env, jclass cls, jobject textView) 
+JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextView_gtk_1text_1view_1get_1tabs
+		(JNIEnv *env, jclass cls, jobject textView) 
 {
+	PangoTabArray *tab_array;
     GtkTextView *textView_g = 
         (GtkTextView *)getPointerFromHandle(env, textView);
-    return getHandleFromPointer(env, gtk_text_view_get_tabs (textView_g));
+    tab_array = gtk_text_view_get_tabs (textView_g);
+    return getGBoxedHandle(env, tab_array, PANGO_TYPE_TAB_ARRAY, NULL, 
+    		(GBoxedFreeFunc) pango_tab_array_free);
 }
 
 /*
@@ -757,11 +776,16 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextView_gtk_1text_1view_1get_1tabs (
  * Method:    gtk_text_view_get_default_attributes
  * Signature: (I)I
  */
-JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextView_gtk_1text_1view_1get_1default_1attributes (JNIEnv *env, jclass cls, jobject textView) 
+JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextView_gtk_1text_1view_1get_1default_1attributes
+		(JNIEnv *env, jclass cls, jobject textView) 
 {
+	GtkTextAttributes *attributes;
     GtkTextView *textView_g = 
         (GtkTextView *)getPointerFromHandle(env, textView);
-    return getHandleFromPointer(env, gtk_text_view_get_default_attributes (textView_g));
+    attributes = gtk_text_view_get_default_attributes (textView_g);
+    return getGBoxedHandle(env, attributes,
+    		GTK_TYPE_TEXT_ATTRIBUTES, NULL, (GBoxedFreeFunc)
+    		gtk_text_attributes_unref);
 }
 
 JNIEXPORT void JNICALL Java_org_gnu_gtk_TextView_gtk_1text_1view_1set_1accepts_1tab (JNIEnv *env, jclass cls, jobject textView, jboolean setting) 
