@@ -10,7 +10,8 @@
 #include <jni.h>
 #include <sys/types.h>
 #include <gtk/gtk.h>
-#include "jg_jnu.h"
+#include <jg_jnu.h>
+#include "gtk_java.h"
 
 #ifdef __cplusplus
 extern "C" 
@@ -34,7 +35,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gtk_ToolItem_gtk_1tool_1item_1get_1type(JNIE
  */
 JNIEXPORT jobject JNICALL Java_org_gnu_gtk_ToolItem_gtk_1tool_1item_1new(JNIEnv *env, jclass cls)
 {
-    return getHandleFromPointer(env, gtk_tool_item_new());
+    return getGObjectHandle(env, (GObject *) gtk_tool_item_new());
 }
 
 /*
@@ -240,10 +241,11 @@ JNIEXPORT jint JNICALL Java_org_gnu_gtk_ToolItem_gtk_1tool_1item_1get_1relief_1s
  * Method:    gtk_tool_item_retrieve_proxy_menu_item
  * Signature: (I)I
  */
-JNIEXPORT jobject JNICALL Java_org_gnu_gtk_ToolItem_gtk_1tool_1item_1retrieve_1proxy_1menu_1item(JNIEnv *env, jclass cls, jobject item)
+JNIEXPORT jobject JNICALL Java_org_gnu_gtk_ToolItem_gtk_1tool_1item_1retrieve_1proxy_1menu_1item
+		(JNIEnv *env, jclass cls, jobject item)
 {
     GtkToolItem *item_g = (GtkToolItem*)getPointerFromHandle(env, item);
-    return getHandleFromPointer(env, gtk_tool_item_retrieve_proxy_menu_item(item_g));
+    return getGObjectHandle(env, (GObject *) gtk_tool_item_retrieve_proxy_menu_item(item_g));
 }
 
 /*
@@ -255,7 +257,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_ToolItem_gtk_1tool_1item_1get_1proxy_
 {
     GtkToolItem *item_g = (GtkToolItem*)getPointerFromHandle(env, item);
     const gchar* m = (*env)->GetStringUTFChars(env, menuId, NULL);
-    jobject ret = getHandleFromPointer(env, gtk_tool_item_get_proxy_menu_item(item_g, m));
+    jobject ret = getGObjectHandle(env, (GObject *) gtk_tool_item_get_proxy_menu_item(item_g, m));
     (*env)->ReleaseStringUTFChars(env, menuId, m);
     return ret;
 }
