@@ -87,7 +87,7 @@ JNIEXPORT jintArray JNICALL Java_org_gnu_gtk_TreeViewColumn_gtk_1tree_1view_1col
 {
     GtkTreeViewColumn *treeColumn_g = 
         (GtkTreeViewColumn *)getPointerFromHandle(env, treeColumn);
-    return getHandleArrayFromGList(env,gtk_tree_view_column_get_cell_renderers(treeColumn_g));
+    return getGObjectHandlesFromGList(env,gtk_tree_view_column_get_cell_renderers(treeColumn_g));
 }
 
 /*
