@@ -9,27 +9,25 @@
 
 #include <jni.h>
 #include <pango/pango.h>
-#include "jg_jnu.h"
+#include <jg_jnu.h>
+#include "gtk_java.h"
 
 #ifdef __cplusplus
 extern "C" 
 {
 #endif
 
-
-PangoLanguage * PangoAttrLanguage_get_value (PangoAttrLanguage * cptr) 
-{
-    return cptr->value;
-}
-
 /*
  * Class:     org.gnu.pango.AttrLanguage
  * Method:    getValue
  */
-JNIEXPORT jobject JNICALL Java_org_gnu_pango_AttrLanguage_getValue (JNIEnv *env, jclass cls, jobject obj) 
+JNIEXPORT jobject JNICALL Java_org_gnu_pango_AttrLanguage_getValue 
+  (JNIEnv *env, jclass cls, jobject obj) 
 {
-    PangoAttrLanguage *obj_g = (PangoAttrLanguage *)getPointerFromHandle(env, obj);
-    return getHandleFromPointer(env, PangoAttrLanguage_get_value (obj_g));
+    PangoAttrLanguage *obj_g = 
+        (PangoAttrLanguage *)getPointerFromHandle(env, obj);
+    return getGBoxedHandle(env, obj_g->value, PANGO_TYPE_LANGUAGE,
+                           NULL, NULL);
 }
 
 #ifdef __cplusplus
